summaryrefslogtreecommitdiffstats
path: root/src/DotNetOpenAuth.OpenId
diff options
context:
space:
mode:
Diffstat (limited to 'src/DotNetOpenAuth.OpenId')
-rw-r--r--src/DotNetOpenAuth.OpenId/DotNetOpenAuth.OpenId.csproj9
-rw-r--r--src/DotNetOpenAuth.OpenId/OpenId/Behaviors/AXFetchAsSregTransformBase.cs (renamed from src/DotNetOpenAuth.OpenId/OpenId/Behaviors/AXFetchAsSregTransform.cs)18
-rw-r--r--src/DotNetOpenAuth.OpenId/OpenId/Behaviors/GsaIcamProfileBase.cs (renamed from src/DotNetOpenAuth.OpenId/OpenId/Behaviors/GsaIcamProfile.cs)8
-rw-r--r--src/DotNetOpenAuth.OpenId/OpenId/Extensions/OpenIdExtensionsInteropHelper.cs (renamed from src/DotNetOpenAuth.OpenId/OpenId/Extensions/ExtensionsInteropHelper.cs)4
-rw-r--r--src/DotNetOpenAuth.OpenId/OpenId/Extensions/UI/UIUtilities.cs28
5 files changed, 45 insertions, 22 deletions
diff --git a/src/DotNetOpenAuth.OpenId/DotNetOpenAuth.OpenId.csproj b/src/DotNetOpenAuth.OpenId/DotNetOpenAuth.OpenId.csproj
index 6f032c6..9418ccf 100644
--- a/src/DotNetOpenAuth.OpenId/DotNetOpenAuth.OpenId.csproj
+++ b/src/DotNetOpenAuth.OpenId/DotNetOpenAuth.OpenId.csproj
@@ -31,13 +31,13 @@
<Compile Include="OpenIdXrdsHelper.cs" />
<Compile Include="OpenId\Association.cs" />
<Compile Include="OpenId\AuthenticationRequestMode.cs" />
- <Compile Include="OpenId\Behaviors\AXFetchAsSregTransform.cs" />
+ <Compile Include="OpenId\Behaviors\AXFetchAsSregTransformBase.cs" />
<Compile Include="OpenId\Behaviors\BehaviorStrings.Designer.cs">
<AutoGen>True</AutoGen>
<DesignTime>True</DesignTime>
<DependentUpon>BehaviorStrings.resx</DependentUpon>
</Compile>
- <Compile Include="OpenId\Behaviors\GsaIcamProfile.cs" />
+ <Compile Include="OpenId\Behaviors\GsaIcamProfileBase.cs" />
<Compile Include="OpenId\ChannelElements\BackwardCompatibilityBindingElement.cs" />
<Compile Include="OpenId\ChannelElements\SigningBindingElementContract.cs" />
<Compile Include="OpenId\ChannelElements\ExtensionsBindingElement.cs" />
@@ -85,9 +85,10 @@
<Compile Include="OpenId\Extensions\UI\UIConstants.cs" />
<Compile Include="OpenId\Extensions\UI\UIModes.cs" />
<Compile Include="OpenId\Extensions\UI\UIRequest.cs" />
+ <Compile Include="OpenId\Extensions\UI\UIUtilities.cs" />
<Compile Include="OpenId\Identifier.cs" />
<Compile Include="OpenId\IdentifierContract.cs" />
- <Compile Include="OpenId\Extensions\ExtensionsInteropHelper.cs" />
+ <Compile Include="OpenId\Extensions\OpenIdExtensionsInteropHelper.cs" />
<Compile Include="OpenId\IdentifierDiscoveryResult.cs" />
<Compile Include="OpenId\IIdentifierDiscoveryService.cs" />
<Compile Include="OpenId\IProviderEndpoint.cs" />
@@ -176,7 +177,7 @@
<Project>{60426312-6AE5-4835-8667-37EDEA670222}</Project>
<Name>DotNetOpenAuth.Messaging</Name>
</ProjectReference>
- <ProjectReference Include="..\Org.Mentalis.Security.Cryptography\Org.Mentalis.Security.Cryptography.csproj" Condition=" '$(ExcludeDiffieHellman)' != 'true' " >
+ <ProjectReference Include="..\Org.Mentalis.Security.Cryptography\Org.Mentalis.Security.Cryptography.csproj" Condition=" '$(ExcludeDiffieHellman)' != 'true' ">
<Project>{26DC877F-5987-48DD-9DDB-E62F2DE0E150}</Project>
<Name>Org.Mentalis.Security.Cryptography</Name>
</ProjectReference>
diff --git a/src/DotNetOpenAuth.OpenId/OpenId/Extensions/ExtensionsInteropHelper.cs b/src/DotNetOpenAuth.OpenId/OpenId/Extensions/OpenIdExtensionsInteropHelper.cs
index f0af03d..fb6202e 100644
--- a/src/DotNetOpenAuth.OpenId/OpenId/Extensions/ExtensionsInteropHelper.cs
+++ b/src/DotNetOpenAuth.OpenId/OpenId/Extensions/OpenIdExtensionsInteropHelper.cs
@@ -1,5 +1,5 @@
//-----------------------------------------------------------------------
-// <copyright file="ExtensionsInteropHelper.cs" company="Andrew Arnott">
+// <copyright file="OpenIdExtensionsInteropHelper.cs" company="Andrew Arnott">
// Copyright (c) Andrew Arnott. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
@@ -19,7 +19,7 @@ namespace DotNetOpenAuth.OpenId.Extensions {
/// A set of methods designed to assist in improving interop across different
/// OpenID implementations and their extensions.
/// </summary>
- internal static class ExtensionsInteropHelper {
+ internal static class OpenIdExtensionsInteropHelper {
/// <summary>
/// The gender decoder to translate AX genders to Sreg.
/// </summary>
diff --git a/src/DotNetOpenAuth.OpenId/OpenId/Extensions/UI/UIUtilities.cs b/src/DotNetOpenAuth.OpenId/OpenId/Extensions/UI/UIUtilities.cs
new file mode 100644
index 0000000..478666b
--- /dev/null
+++ b/src/DotNetOpenAuth.OpenId/OpenId/Extensions/UI/UIUtilities.cs
@@ -0,0 +1,28 @@
+//-----------------------------------------------------------------------
+// <copyright file="UIUtilities.cs" company="Andrew Arnott">
+// Copyright (c) Andrew Arnott. All rights reserved.
+// </copyright>
+//-----------------------------------------------------------------------
+
+namespace DotNetOpenAuth.OpenId.Extensions.UI {
+ using System;
+ using System.Diagnostics.Contracts;
+ using System.Globalization;
+ using DotNetOpenAuth.Messaging;
+ using DotNetOpenAuth.OpenId.RelyingParty;
+
+ /// <summary>
+ /// Constants used in implementing support for the UI extension.
+ /// </summary>
+ public static class UIUtilities {
+ /// <summary>
+ /// The required width of the popup window the relying party creates for the provider.
+ /// </summary>
+ public const int PopupWidth = 500; // UI extension calls for 450px, but Yahoo needs 500px
+
+ /// <summary>
+ /// The required height of the popup window the relying party creates for the provider.
+ /// </summary>
+ public const int PopupHeight = 500;
+ }
+}
diff --git a/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/AXFetchAsSregTransform.cs b/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/AXFetchAsSregTransformBase.cs
index 8670a0e..41e6b8e 100644
--- a/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/AXFetchAsSregTransform.cs
+++ b/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/AXFetchAsSregTransformBase.cs
@@ -1,5 +1,5 @@
//-----------------------------------------------------------------------
-// <copyright file="AXFetchAsSregTransform.cs" company="Andrew Arnott">
+// <copyright file="AXFetchAsSregTransformBase.cs" company="Andrew Arnott">
// Copyright (c) Andrew Arnott. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
@@ -21,23 +21,17 @@ namespace DotNetOpenAuth.OpenId.Behaviors {
/// to the originally requested extension and format.
/// </summary>
[SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Sreg", Justification = "Abbreviation")]
- public abstract class AXFetchAsSregTransform {
+ public abstract class AXFetchAsSregTransformBase {
/// <summary>
/// Initializes static members of the <see cref="AXFetchAsSregTransform"/> class.
/// </summary>
- static AXFetchAsSregTransform() {
- AXFormats = AXAttributeFormats.Common;
- }
-
- /// <summary>
- /// Initializes a new instance of the <see cref="AXFetchAsSregTransform"/> class.
- /// </summary>
- protected AXFetchAsSregTransform() {
+ protected AXFetchAsSregTransformBase() {
+ this.AXFormats = AXAttributeFormats.Common;
}
/// <summary>
/// Gets or sets the AX attribute type URI formats this transform is willing to work with.
/// </summary>
- public static AXAttributeFormats AXFormats { get; set; }
+ public AXAttributeFormats AXFormats { get; set; }
}
}
@@ -21,23 +21,17 @@ namespace DotNetOpenAuth.OpenId.Behaviors {
/// <summary>
- /// Initializes static members of the <see cref="AXFetchAsSregTransform"/> class.
+ /// Initializes a new instance of the <see cref="AXFetchAsSregTransformBase"/> class.
/// </summary>
diff --git a/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/GsaIcamProfile.cs b/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/GsaIcamProfileBase.cs
index c84e570..25a4e59 100644
--- a/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/GsaIcamProfile.cs
+++ b/src/DotNetOpenAuth.OpenId/OpenId/Behaviors/GsaIcamProfileBase.cs
@@ -1,5 +1,5 @@
//-----------------------------------------------------------------------
-// <copyright file="GsaIcamProfile.cs" company="Andrew Arnott">
+// <copyright file="GsaIcamProfileBase.cs" company="Andrew Arnott">
// Copyright (c) Andrew Arnott. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
@@ -26,16 +26,16 @@ namespace DotNetOpenAuth.OpenId.Behaviors {
/// </remarks>
[Serializable]
[SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Icam", Justification = "Acronym")]
- public abstract class GsaIcamProfile {
+ public abstract class GsaIcamProfileBase {
/// <summary>
/// Backing field for the <see cref="DisableSslRequirement"/> static property.
/// </summary>
private static bool disableSslRequirement = DotNetOpenAuthSection.Messaging.RelaxSslRequirements;
/// <summary>
/// Initializes a new instance of the <see cref="GsaIcamProfile"/> class.
/// </summary>
- public GsaIcamProfile() {
+ public GsaIcamProfileBase() {
if (DisableSslRequirement) {
Logger.OpenId.Warn("GSA level 1 behavior has its RequireSsl requirement disabled.");
}
@@ -26,16 +26,16 @@ namespace DotNetOpenAuth.OpenId.Behaviors {
private static bool disableSslRequirement = DotNetOpenAuthSection.Messaging.RelaxSslRequirements;
/// <summary>
- /// Initializes a new instance of the <see cref="GsaIcamProfile"/> class.
+ /// Initializes a new instance of the <see cref="GsaIcamProfileBase"/> class.
/// </summary>